import React from "react";
import { FormInput, SubmitButton } from "../components"; 
import { Form, Link, redirect } from "react-router-dom";
import axios from "axios";
import { REGISTERURL } from "./data";
import { toast } from "react-toastify";

export const action = async ({ request }) => {
    console.log("******************************")
    const formData = await request.formData();
    const data = Object.fromEntries(formData);
    try {
        const response = await axios.post(REGISTERURL, data, {
            headers: {
                "Content-Type": "multipart/form-data"
            }
        });
        console.log(response.data);
        toast.success("Account created successfully!!");
        return redirect("/login");
    } catch (error) {
        console.log(error);
        return null;
    }
    
};


const RegisterPage = () => {
    return (
        <div className="flex items-center justify-center min-h-screen bg-gray-100">
            <div className="w-full max-w-md p-6 bg-white rounded-lg shadow-md">
                <h2 className="text-2xl font-semibold text-center mb-4">Register</h2>
                <Form method="POST" action="/register" className="p-8 bg-base-100 flex flex-col gap-y-4">  
                    <FormInput
                        label="USERNAME"
                        name="identifier"
                        type="text"
                        defaultValue=""
                    />                  
                    <FormInput
                        label="EMAIL"
                        name="email"
                        type="email"
                        defaultValue=""
                    />
                    <FormInput
                        label="PASSWORD"
                        name="password"
                        type="password"
                        defaultValue=""
                    />                                       
                    <SubmitButton text="Register" />               
                </Form>
                <p className="text-center">
                    Already a member?{" "}
                    <Link to="/login" className="ml-2 link-accent">
                        Login
                    </Link>
                </p>
            </div>
            
        </div>
        
    );
};

export default RegisterPage;
