import React from "react";
import { useEffect, useState } from "react";
import axios from "axios";
import { toast } from "react-toastify";
import UserItem from "./UserItem";
import MenuTitle from "../components/MenuTitle";
import { useDispatch, useSelector } from "react-redux";
import { fetchUsers, resetUsers, clearList, removeUser  } from "../features/users/userSlice";


const URL="https://randomuser.me/api/?results=10";

const Users = () => {
    const { randomUsers, isLoading } = useSelector((store) => store.users);
    const dispatch = useDispatch();

    useEffect(() => {
        dispatch(fetchUsers());
    }, []);

    const handleClearList = () => {
        dispatch(clearList());
    };

    const handleReset = () => {
        dispatch(resetUsers());
    };

    const handleRemove = (uuid) => {
        dispatch(removeUser(uuid));
    };

    if(isLoading) {
        return <h4>Loading...</h4>;
    }

    return (
        <section>
            <MenuTitle title="Board of Global Executives" />
            <div className="button-container">
                {randomUsers.length > 0 ? (
                    <button className="centered-button" onClick={handleClearList}>
                        Clear All
                    </button>
                ) : (
                    <button className="centered-button" onClick={handleReset}>
                        Reset Users
                    </button>
                )}
            </div>
            <div className="user-container">
                {randomUsers.map((user) => {
                    return <UserItem user={user} key={user.login.uuid} remove={() => handleRemove(user.login.uuid)} />
                })}
            </div>
        </section>
    );
};

export default Users;
